pub struct Continuation {
pub upstream: Upstream,
pub thread_id: String,
pub mcp_sessions: IndexMap<String, String>,
}Fields
upstream: Upstreamthread_id: Stringmcp_sessions: IndexMap<String, String>Trait Implementations
Sourceimpl Clone for Continuation
impl Clone for Continuation
Sourcefn clone(&self) -> Continuation
fn clone(&self) -> Continuation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Continuation
impl Debug for Continuation
Sourceimpl<'de> Deserialize<'de> for Continuation
impl<'de> Deserialize<'de> for Continuation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<Continuation> for Continuation
impl From<Continuation> for Continuation
Sourcefn from(inner: Continuation) -> Self
fn from(inner: Continuation) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for Continuation
impl JsonSchema for Continuation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for Continuation
impl PartialEq for Continuation
Sourcefn eq(&self, other: &Continuation) -> bool
fn eq(&self, other: &Continuation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for Continuation
impl Serialize for Continuation
impl StructuralPartialEq for Continuation