pub struct AssistantMessageLog {
pub content: Option<RichContentLog>,
pub name: Option<String>,
pub refusal: Option<LogReference>,
pub tool_calls: Option<Vec<LogReference>>,
pub reasoning: Option<LogReference>,
}Fields
content: Option<RichContentLog>name: Option<String>refusal: Option<LogReference>tool_calls: Option<Vec<LogReference>>reasoning: Option<LogReference>Trait Implementations
Sourceimpl Clone for AssistantMessageLog
impl Clone for AssistantMessageLog
Sourcefn clone(&self) -> AssistantMessageLog
fn clone(&self) -> AssistantMessageLog
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AssistantMessageLog
impl Debug for AssistantMessageLog
Sourceimpl<'de> Deserialize<'de> for AssistantMessageLog
impl<'de> Deserialize<'de> for AssistantMessageLog
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AssistantMessageLog
impl JsonSchema for AssistantMessageLog
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AssistantMessageLog
impl RefUnwindSafe for AssistantMessageLog
impl Send for AssistantMessageLog
impl Sync for AssistantMessageLog
impl Unpin for AssistantMessageLog
impl UnsafeUnpin for AssistantMessageLog
impl UnwindSafe for AssistantMessageLog