pub struct AssistantToolCallFunction {
pub name: String,
pub arguments: String,
}Expand description
Details of a function call made by the assistant.
Fields
name: StringThe name of the function to call.
arguments: StringThe arguments to pass to the function, as a JSON string.
Implementations