pub struct DeveloperMessageLog {
pub content: SimpleContentLog,
pub name: Option<String>,
}Fields
content: SimpleContentLogname: Option<String>Trait Implementations
Sourceimpl Clone for DeveloperMessageLog
impl Clone for DeveloperMessageLog
Sourcefn clone(&self) -> DeveloperMessageLog
fn clone(&self) -> DeveloperMessageLog
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeveloperMessageLog
impl Debug for DeveloperMessageLog
Sourceimpl<'de> Deserialize<'de> for DeveloperMessageLog
impl<'de> Deserialize<'de> for DeveloperMessageLog
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DeveloperMessageLog
impl JsonSchema for DeveloperMessageLog
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DeveloperMessageLog
impl RefUnwindSafe for DeveloperMessageLog
impl Send for DeveloperMessageLog
impl Sync for DeveloperMessageLog
impl Unpin for DeveloperMessageLog
impl UnsafeUnpin for DeveloperMessageLog
impl UnwindSafe for DeveloperMessageLog