pub enum InlineAgentBaseWithFallbacksOrRemote {
AgentBase(InlineAgentBaseWithFallbacks),
Remote(RemotePath),
}Expand description
An agent specification that is either an inline agent base with fallbacks or a remote path reference.
Used in swarm definitions to allow agents to be specified inline (with optional fallbacks) or resolved from a remote source via a hashmap during conversion.
Variants
AgentBase(InlineAgentBaseWithFallbacks)
Remote(RemotePath)