pub struct DisableApiKeyRequest {
pub api_key: ApiKey,
}Expand description
Request to disable an existing API key.
Once disabled, the API key can no longer be used for authentication. This action is reversible only by creating a new key.
Fields
api_key: ApiKeyThe API key to disable.