pub struct LaboratoryAttachment {
pub id: String,
pub attached_at: String,
pub attached_by: Option<String>,
pub machine: Option<String>,
pub machine_state: Option<String>,
}Expand description
One laboratory attachment on an agent, as surfaced by
agents instances get.
Fields
id: StringThe attached laboratory’s id.
attached_at: StringRFC3339 — when it was attached.
attached_by: Option<String>The AIH that ran the attach. None on attachments predating
attacher tracking.
machine: Option<String>The machine id of the laboratory host the attachment row
records — laboratory ids are only unique per (machine, state).
None on rows predating machine tracking.
machine_state: Option<String>The state the attachment row records, paired with machine.