pub struct RequestMessageUserPart {
pub id: i64,
pub delivered_at: String,
pub type: RequestMessageUserPartType,
}Expand description
One content part of a user request message. Its id addresses the
stored content the same way a response part’s id does — pass it
to agents logs read id <n>.
Fields
id: i64logs.messages."index" for this row.
delivered_at: Stringtype: RequestMessageUserPartTypeTrait Implementations
Sourceimpl Clone for RequestMessageUserPart
impl Clone for RequestMessageUserPart
Sourcefn clone(&self) -> RequestMessageUserPart
fn clone(&self) -> RequestMessageUserPart
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RequestMessageUserPart
impl Debug for RequestMessageUserPart
Sourceimpl<'de> Deserialize<'de> for RequestMessageUserPart
impl<'de> Deserialize<'de> for RequestMessageUserPart
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RequestMessageUserPart
Sourceimpl JsonSchema for RequestMessageUserPart
impl JsonSchema for RequestMessageUserPart
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RequestMessageUserPart
impl PartialEq for RequestMessageUserPart
Sourcefn eq(&self, other: &RequestMessageUserPart) -> bool
fn eq(&self, other: &RequestMessageUserPart) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RequestMessageUserPart
impl Serialize for RequestMessageUserPart
impl StructuralPartialEq for RequestMessageUserPart