pub struct VectorRequestChoice {
pub key: String,
pub parts: Vec<VectorRequestChoicePart>,
}Expand description
One choice in a VectorRequestChoices block: this agent’s inline
voting key for the choice plus the choice’s content parts (in
request order). The key is returned inline — no read id needed.
Fields
key: StringThe prefix-tree voting key this agent assigned to the choice.
parts: Vec<VectorRequestChoicePart>Trait Implementations
Sourceimpl Clone for VectorRequestChoice
impl Clone for VectorRequestChoice
Sourcefn clone(&self) -> VectorRequestChoice
fn clone(&self) -> VectorRequestChoice
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VectorRequestChoice
impl Debug for VectorRequestChoice
Sourceimpl<'de> Deserialize<'de> for VectorRequestChoice
impl<'de> Deserialize<'de> for VectorRequestChoice
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for VectorRequestChoice
Sourceimpl JsonSchema for VectorRequestChoice
impl JsonSchema for VectorRequestChoice
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VectorRequestChoice
impl PartialEq for VectorRequestChoice
Sourcefn eq(&self, other: &VectorRequestChoice) -> bool
fn eq(&self, other: &VectorRequestChoice) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for VectorRequestChoice
impl Serialize for VectorRequestChoice
impl StructuralPartialEq for VectorRequestChoice