pub struct VectorRequestChoicePart {
pub id: i64,
pub delivered_at: String,
pub type: VectorRequestChoicePartType,
}Expand description
One content part of a vector-completion request choice. id
addresses the stored content via agents logs read id <n>.
Fields
id: i64logs.messages."index" for this row.
delivered_at: Stringtype: VectorRequestChoicePartTypeTrait Implementations
Sourceimpl Clone for VectorRequestChoicePart
impl Clone for VectorRequestChoicePart
Sourcefn clone(&self) -> VectorRequestChoicePart
fn clone(&self) -> VectorRequestChoicePart
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VectorRequestChoicePart
impl Debug for VectorRequestChoicePart
Sourceimpl<'de> Deserialize<'de> for VectorRequestChoicePart
impl<'de> Deserialize<'de> for VectorRequestChoicePart
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for VectorRequestChoicePart
Sourceimpl JsonSchema for VectorRequestChoicePart
impl JsonSchema for VectorRequestChoicePart
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VectorRequestChoicePart
impl PartialEq for VectorRequestChoicePart
Sourceimpl Serialize for VectorRequestChoicePart
impl Serialize for VectorRequestChoicePart
impl StructuralPartialEq for VectorRequestChoicePart