pub struct ToolResponsePart {
pub id: i64,
pub delivered_at: String,
pub type: ToolResponsePartType,
}Expand description
One row inside a ToolResponse block.
Fields
id: i64logs.messages."index" for this row. Pass to
agents logs read id <n> for the typed body.
delivered_at: Stringtype: ToolResponsePartTypeTrait Implementations
Sourceimpl Clone for ToolResponsePart
impl Clone for ToolResponsePart
Sourcefn clone(&self) -> ToolResponsePart
fn clone(&self) -> ToolResponsePart
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolResponsePart
impl Debug for ToolResponsePart
Sourceimpl<'de> Deserialize<'de> for ToolResponsePart
impl<'de> Deserialize<'de> for ToolResponsePart
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ToolResponsePart
Sourceimpl JsonSchema for ToolResponsePart
impl JsonSchema for ToolResponsePart
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ToolResponsePart
impl PartialEq for ToolResponsePart
Sourcefn eq(&self, other: &ToolResponsePart) -> bool
fn eq(&self, other: &ToolResponsePart) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ToolResponsePart
impl Serialize for ToolResponsePart
impl StructuralPartialEq for ToolResponsePart