pub struct AgentActiveResponseItem {
pub type: AgentActiveType,
pub agent_instance_hierarchy: String,
}Expand description
This agent’s lock was held by a live owner — it is already active and will drain its own queue; nothing was spawned for it.
Fields
type: AgentActiveTypeagent_instance_hierarchy: StringTrait Implementations
Sourceimpl Clone for AgentActiveResponseItem
impl Clone for AgentActiveResponseItem
Sourcefn clone(&self) -> AgentActiveResponseItem
fn clone(&self) -> AgentActiveResponseItem
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentActiveResponseItem
impl Debug for AgentActiveResponseItem
Sourceimpl<'de> Deserialize<'de> for AgentActiveResponseItem
impl<'de> Deserialize<'de> for AgentActiveResponseItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AgentActiveResponseItem
Sourceimpl JsonSchema for AgentActiveResponseItem
impl JsonSchema for AgentActiveResponseItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AgentActiveResponseItem
impl PartialEq for AgentActiveResponseItem
Sourcefn eq(&self, other: &AgentActiveResponseItem) -> bool
fn eq(&self, other: &AgentActiveResponseItem) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AgentActiveResponseItem
impl Serialize for AgentActiveResponseItem
impl StructuralPartialEq for AgentActiveResponseItem