pub struct AgentSpawnedResponseItem {
pub type: AgentSpawnedType,
pub agent_instance_hierarchy: String,
}Expand description
This agent’s lock was won and its spawn has started; its output
follows as ValueResponseItems (in stream_spawns mode).
Fields
type: AgentSpawnedTypeagent_instance_hierarchy: StringTrait Implementations
Sourceimpl Clone for AgentSpawnedResponseItem
impl Clone for AgentSpawnedResponseItem
Sourcefn clone(&self) -> AgentSpawnedResponseItem
fn clone(&self) -> AgentSpawnedResponseItem
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentSpawnedResponseItem
impl Debug for AgentSpawnedResponseItem
Sourceimpl<'de> Deserialize<'de> for AgentSpawnedResponseItem
impl<'de> Deserialize<'de> for AgentSpawnedResponseItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AgentSpawnedResponseItem
Sourceimpl JsonSchema for AgentSpawnedResponseItem
impl JsonSchema for AgentSpawnedResponseItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AgentSpawnedResponseItem
impl PartialEq for AgentSpawnedResponseItem
Sourcefn eq(&self, other: &AgentSpawnedResponseItem) -> bool
fn eq(&self, other: &AgentSpawnedResponseItem) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AgentSpawnedResponseItem
impl Serialize for AgentSpawnedResponseItem
impl StructuralPartialEq for AgentSpawnedResponseItem