pub struct QueuePart {
pub id: i64,
pub type: QueuePartType,
}Expand description
One row inside a ResponseItem block — a
message_queue_contents entry. The id is the
message_queue_contents.id, which you pass to
agents queue read id <n> to drill into the body.
enqueued_at is on the enclosing block, not here
(one block = one message_queue parent row, sharing one
enqueued_at).
Fields
id: i64type: QueuePartTypeTrait Implementations
Sourceimpl<'de> Deserialize<'de> for QueuePart
impl<'de> Deserialize<'de> for QueuePart
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for QueuePart
Sourceimpl JsonSchema for QueuePart
impl JsonSchema for QueuePart
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for QueuePart