pub struct Column {
pub name: String,
pub type: String,
}Expand description
One result column. r#type is the Postgres pg_type.typname
(e.g. "int8", "text", "jsonb", "timestamptz"). Callers
needing precision/scale/array-element-type can inspect the
name; richer typeinfo is deferred.
Fields
name: Stringtype: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Column
impl<'de> Deserialize<'de> for Column
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Column
Sourceimpl JsonSchema for Column
impl JsonSchema for Column
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for Column