pub struct Args {Show 14 fields
pub function_inline: String,
pub profile_inline: String,
pub input_inline: Option<String>,
pub input_python_inline: Option<String>,
pub input_python_file: Option<PathBuf>,
pub continuation: Option<String>,
pub retry_token: Option<String>,
pub seed: Option<i64>,
pub split: bool,
pub invert: bool,
pub dangerous_advanced: Option<String>,
pub pool: Option<usize>,
pub rounds: Option<usize>,
pub jq: Option<String>,
}Fields
function_inline: StringInline JSON function definition.
profile_inline: StringInline JSON profile definition.
input_inline: Option<String>Inline JSON input value.
input_python_inline: Option<String>Inline Python that produces the input value.
input_python_file: Option<PathBuf>Path to a Python file that produces the input value.
continuation: Option<String>Continuation token from a previous response.
retry_token: Option<String>Retry token from a previous execution.
seed: Option<i64>Seed for deterministic mock responses.
split: boolTreat input as an array and execute once per element.
invert: boolInvert outputs after expressions evaluate.
dangerous_advanced: Option<String>Advanced opt-in flags as inline JSON.
pool: Option<usize>How many vector responses per execution.
rounds: Option<usize>How many sequential rounds of comparison.
jq: Option<String>jq filter applied to the JSON output.