pub struct RequestParams {
pub name: String,
pub spec: String,
pub depth: u64,
pub min_branch_width: u64,
pub max_branch_width: u64,
pub min_leaf_width: u64,
pub max_leaf_width: u64,
}Fields
name: Stringspec: Stringdepth: u64min_branch_width: u64max_branch_width: u64min_leaf_width: u64max_leaf_width: u64Trait Implementations
Sourceimpl Clone for RequestParams
impl Clone for RequestParams
Sourcefn clone(&self) -> RequestParams
fn clone(&self) -> RequestParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RequestParams
impl Debug for RequestParams
Sourceimpl<'de> Deserialize<'de> for RequestParams
impl<'de> Deserialize<'de> for RequestParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RequestParams
impl JsonSchema for RequestParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RequestParams
impl PartialEq for RequestParams
Sourcefn eq(&self, other: &RequestParams) -> bool
fn eq(&self, other: &RequestParams) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RequestParams
impl Serialize for RequestParams
impl StructuralPartialEq for RequestParams