pub struct ResponseFavorite {
pub name: String,
pub path: RemotePathCommitOptional,
pub note: String,
}Fields
name: Stringpath: RemotePathCommitOptionalnote: StringTrait Implementations
Sourceimpl Clone for ResponseFavorite
impl Clone for ResponseFavorite
Sourcefn clone(&self) -> ResponseFavorite
fn clone(&self) -> ResponseFavorite
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResponseFavorite
impl Debug for ResponseFavorite
Sourceimpl<'de> Deserialize<'de> for ResponseFavorite
impl<'de> Deserialize<'de> for ResponseFavorite
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResponseFavorite
impl JsonSchema for ResponseFavorite
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ResponseFavorite
impl PartialEq for ResponseFavorite
Sourcefn eq(&self, other: &ResponseFavorite) -> bool
fn eq(&self, other: &ResponseFavorite) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ResponseFavorite
impl Serialize for ResponseFavorite
impl StructuralPartialEq for ResponseFavorite