pub struct ResponseBinaries {
pub linux_x86_64: Option<String>,
pub linux_aarch64: Option<String>,
pub windows_x86_64: Option<String>,
pub windows_aarch64: Option<String>,
pub macos_x86_64: Option<String>,
pub macos_aarch64: Option<String>,
}Fields
linux_x86_64: Option<String>linux_aarch64: Option<String>windows_x86_64: Option<String>windows_aarch64: Option<String>macos_x86_64: Option<String>macos_aarch64: Option<String>Trait Implementations
Sourceimpl Clone for ResponseBinaries
impl Clone for ResponseBinaries
Sourcefn clone(&self) -> ResponseBinaries
fn clone(&self) -> ResponseBinaries
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResponseBinaries
impl Debug for ResponseBinaries
Sourceimpl Default for ResponseBinaries
impl Default for ResponseBinaries
Sourcefn default() -> ResponseBinaries
fn default() -> ResponseBinaries
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ResponseBinaries
impl<'de> Deserialize<'de> for ResponseBinaries
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ResponseBinaries
Sourceimpl JsonSchema for ResponseBinaries
impl JsonSchema for ResponseBinaries
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ResponseBinaries
impl PartialEq for ResponseBinaries
Sourcefn eq(&self, other: &ResponseBinaries) -> bool
fn eq(&self, other: &ResponseBinaries) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ResponseBinaries
impl Serialize for ResponseBinaries
impl StructuralPartialEq for ResponseBinaries