pub struct ResponseMcpServer {
pub name: String,
pub authorization: bool,
}Fields
name: StringTrait Implementations
Sourceimpl Clone for ResponseMcpServer
impl Clone for ResponseMcpServer
Sourcefn clone(&self) -> ResponseMcpServer
fn clone(&self) -> ResponseMcpServer
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResponseMcpServer
impl Debug for ResponseMcpServer
Sourceimpl<'de> Deserialize<'de> for ResponseMcpServer
impl<'de> Deserialize<'de> for ResponseMcpServer
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ResponseMcpServer
Sourceimpl JsonSchema for ResponseMcpServer
impl JsonSchema for ResponseMcpServer
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ResponseMcpServer
impl PartialEq for ResponseMcpServer
Sourcefn eq(&self, other: &ResponseMcpServer) -> bool
fn eq(&self, other: &ResponseMcpServer) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ResponseMcpServer
impl Serialize for ResponseMcpServer
impl StructuralPartialEq for ResponseMcpServer