pub struct ResponseViewerRoute {
pub path: String,
pub method: ResponseHttpMethod,
pub type: String,
}Fields
path: Stringmethod: ResponseHttpMethodtype: StringTrait Implementations
Sourceimpl Clone for ResponseViewerRoute
impl Clone for ResponseViewerRoute
Sourcefn clone(&self) -> ResponseViewerRoute
fn clone(&self) -> ResponseViewerRoute
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResponseViewerRoute
impl Debug for ResponseViewerRoute
Sourceimpl<'de> Deserialize<'de> for ResponseViewerRoute
impl<'de> Deserialize<'de> for ResponseViewerRoute
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ResponseViewerRoute
Sourceimpl JsonSchema for ResponseViewerRoute
impl JsonSchema for ResponseViewerRoute
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ResponseViewerRoute
impl PartialEq for ResponseViewerRoute
Sourcefn eq(&self, other: &ResponseViewerRoute) -> bool
fn eq(&self, other: &ResponseViewerRoute) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ResponseViewerRoute
impl Serialize for ResponseViewerRoute
impl StructuralPartialEq for ResponseViewerRoute