pub struct Mcp {
pub type: McpType,
pub url: String,
}Expand description
Plugin announces a running MCP server URL. The host routes this
through the standard plugin-notification pipeline and dials the
URL the same way it would for an entry in the plugin’s manifest
mcp_servers — runtime announcements are functionally identical
to manifest-time declarations.
The constant type:"mcp" discriminator disambiguates this
variant from the rest of the untagged ResponseItem /
crate::cli::plugins::Output catch-all, mirroring the
type:"error" discriminator on crate::cli::Error.
Fields
type: McpTypeurl: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Mcp
impl<'de> Deserialize<'de> for Mcp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Mcp
impl JsonSchema for Mcp
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for Mcp