pub struct ResponseSchema(pub Schema);Tuple Fields
0: SchemaTrait Implementations
Sourceimpl Clone for ResponseSchema
impl Clone for ResponseSchema
Sourcefn clone(&self) -> ResponseSchema
fn clone(&self) -> ResponseSchema
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CommandResponse for ResponseSchema
Available on crate feature mcp only.
impl CommandResponse for ResponseSchema
Available on crate feature
mcp only.fn into_mcp(self) -> McpResponseItem
Sourceimpl Debug for ResponseSchema
impl Debug for ResponseSchema
Sourceimpl<'de> Deserialize<'de> for ResponseSchema
impl<'de> Deserialize<'de> for ResponseSchema
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResponseSchema
impl JsonSchema for ResponseSchema
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ResponseSchema
impl PartialEq for ResponseSchema
Sourcefn eq(&self, other: &ResponseSchema) -> bool
fn eq(&self, other: &ResponseSchema) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ResponseSchema
impl Serialize for ResponseSchema
impl StructuralPartialEq for ResponseSchema