pub struct Detached {
pub pid: u32,
}Expand description
Emitted by the parent process during --detach once the child has
been spawned. Replaces the prior println!("PID: {pid}").
Wire: {"type":"notification","pid":12345}.
Fields
pid: u32Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Detached
impl<'de> Deserialize<'de> for Detached
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Detached
impl JsonSchema for Detached
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Detached
impl RefUnwindSafe for Detached
impl Send for Detached
impl Sync for Detached
impl Unpin for Detached
impl UnsafeUnpin for Detached
impl UnwindSafe for Detached