pub struct Execution {
pub execution: ExecutionResult,
}Expand description
Result of functions executions create.
Wire: {"type":"notification","execution":{"output":...}}.
Per-task / per-vote / reasoning errors are surfaced live during
streaming via Output::Error notifications (see the CLI’s
streaming handler). They are NOT bundled into this payload.
Fields
execution: ExecutionResultTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Execution
impl<'de> Deserialize<'de> for Execution
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Execution
impl JsonSchema for Execution
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Execution
impl RefUnwindSafe for Execution
impl Send for Execution
impl Sync for Execution
impl Unpin for Execution
impl UnsafeUnpin for Execution
impl UnwindSafe for Execution