pub struct FunctionProfilePair {
pub function: GetFunctionResponse,
pub profile: GetProfileResponse,
}Expand description
The composite body inside a Pair notification.
Fields
function: GetFunctionResponseprofile: GetProfileResponseTrait Implementations
Sourceimpl Clone for FunctionProfilePair
impl Clone for FunctionProfilePair
Sourcefn clone(&self) -> FunctionProfilePair
fn clone(&self) -> FunctionProfilePair
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FunctionProfilePair
impl Debug for FunctionProfilePair
Sourceimpl<'de> Deserialize<'de> for FunctionProfilePair
impl<'de> Deserialize<'de> for FunctionProfilePair
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FunctionProfilePair
impl JsonSchema for FunctionProfilePair
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FunctionProfilePair
impl RefUnwindSafe for FunctionProfilePair
impl Send for FunctionProfilePair
impl Sync for FunctionProfilePair
impl Unpin for FunctionProfilePair
impl UnsafeUnpin for FunctionProfilePair
impl UnwindSafe for FunctionProfilePair