pub struct Inventions {
pub inventions: Vec<InventionResultItem>,
}Expand description
Result of functions inventions recursive create.
Wire: {"type":"notification","inventions":[...InventionResultItem...]}.
Fields
inventions: Vec<InventionResultItem>Trait Implementations
Sourceimpl Clone for Inventions
impl Clone for Inventions
Sourcefn clone(&self) -> Inventions
fn clone(&self) -> Inventions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Inventions
impl Debug for Inventions
Sourceimpl<'de> Deserialize<'de> for Inventions
impl<'de> Deserialize<'de> for Inventions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Inventions
impl JsonSchema for Inventions
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Inventions
impl RefUnwindSafe for Inventions
impl Send for Inventions
impl Sync for Inventions
impl Unpin for Inventions
impl UnsafeUnpin for Inventions
impl UnwindSafe for Inventions