pub struct Cleared {
pub cleared: u64,
}Expand description
Number of log files cleared by <scope> logs clear (or the global
logs clear). Wire: {"type":"notification","cleared":7}.
Fields
cleared: u64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Cleared
impl<'de> Deserialize<'de> for Cleared
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Cleared
impl JsonSchema for Cleared
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Cleared
impl RefUnwindSafe for Cleared
impl Send for Cleared
impl Sync for Cleared
impl Unpin for Cleared
impl UnsafeUnpin for Cleared
impl UnwindSafe for Cleared