pub struct Items<T> {
pub items: Vec<T>,
}Expand description
Generic wire wrapper for every list-style notification:
{"type":"notification","items":[...]}. The element type varies
(e.g. Items<ListItem> for agents list, Items<PairListItem> for
pairs list, Items<crate::filesystem::config::Favorite> for
favorites listings, Items<crate::filesystem::logs::ListItem>
for log listings).
Fields
items: Vec<T>Trait Implementations
Sourceimpl<'de, T> Deserialize<'de> for Items<T>where
T: Deserialize<'de>,
impl<'de, T> Deserialize<'de> for Items<T>where
T: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<T> JsonSchema for Items<T>where
T: JsonSchema,
impl<T> JsonSchema for Items<T>where
T: JsonSchema,
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl<T> Freeze for Items<T>
impl<T> RefUnwindSafe for Items<T>where
T: RefUnwindSafe,
impl<T> Send for Items<T>where
T: Send,
impl<T> Sync for Items<T>where
T: Sync,
impl<T> Unpin for Items<T>where
T: Unpin,
impl<T> UnsafeUnpin for Items<T>
impl<T> UnwindSafe for Items<T>where
T: UnwindSafe,