pub struct LogStreamReady {
pub log_stream_ready: String,
}Expand description
Emitted mid-stream by long-running */create commands once a log
id has been allocated and the log file is available. Replaces the
prior "Logs ID: ..." plaintext sentinel.
Wire: {"type":"notification","log_stream_ready":"<id>"}.
Fields
log_stream_ready: StringTrait Implementations
Sourceimpl Clone for LogStreamReady
impl Clone for LogStreamReady
Sourcefn clone(&self) -> LogStreamReady
fn clone(&self) -> LogStreamReady
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LogStreamReady
impl Debug for LogStreamReady
Sourceimpl<'de> Deserialize<'de> for LogStreamReady
impl<'de> Deserialize<'de> for LogStreamReady
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LogStreamReady
impl JsonSchema for LogStreamReady
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LogStreamReady
impl RefUnwindSafe for LogStreamReady
impl Send for LogStreamReady
impl Sync for LogStreamReady
impl Unpin for LogStreamReady
impl UnsafeUnpin for LogStreamReady
impl UnwindSafe for LogStreamReady