pub struct Published {
pub sha: String,
}Expand description
Result of <resource> publish. The SHA identifies the resulting
commit on the local filesystem repo.
Wire: {"type":"notification","sha":"<commit-sha>"}.
Fields
sha: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Published
impl<'de> Deserialize<'de> for Published
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Published
impl JsonSchema for Published
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Published
impl RefUnwindSafe for Published
impl Send for Published
impl Sync for Published
impl Unpin for Published
impl UnsafeUnpin for Published
impl UnwindSafe for Published