pub struct DropRequest {
pub response_id: String,
}Expand description
Parameters for Payload::Drop. The objectiveai response id whose
entire upstream-connection bucket the CLI should tear down. The id
rides in the payload (not a header) because Drop is a control
message identified solely by its argument.
Fields
response_id: StringTrait Implementations
Sourceimpl Clone for DropRequest
impl Clone for DropRequest
Sourcefn clone(&self) -> DropRequest
fn clone(&self) -> DropRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DropRequest
impl Debug for DropRequest
Sourceimpl<'de> Deserialize<'de> for DropRequest
impl<'de> Deserialize<'de> for DropRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DropRequest
impl JsonSchema for DropRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DropRequest
impl RefUnwindSafe for DropRequest
impl Send for DropRequest
impl Sync for DropRequest
impl Unpin for DropRequest
impl UnsafeUnpin for DropRequest
impl UnwindSafe for DropRequest