pub struct LaboratoryLocalTransferRequest {
pub source_id: String,
pub source_machine: Option<String>,
pub source_machine_state: Option<String>,
pub source_path: String,
pub destination_id: String,
pub destination_machine: Option<String>,
pub destination_machine_state: Option<String>,
pub destination_path: String,
}Expand description
Parameters for Payload::LaboratoryLocalTransfer — identical
shape to LaboratoryTransferRequest; the (machine, state) pairs
are equal by construction (the proxy only picks the local variant
when they match).
Fields
source_id: Stringsource_machine: Option<String>source_machine_state: Option<String>source_path: Stringdestination_id: Stringdestination_machine: Option<String>destination_machine_state: Option<String>destination_path: StringTrait Implementations
Sourceimpl Clone for LaboratoryLocalTransferRequest
impl Clone for LaboratoryLocalTransferRequest
Sourcefn clone(&self) -> LaboratoryLocalTransferRequest
fn clone(&self) -> LaboratoryLocalTransferRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for LaboratoryLocalTransferRequest
impl<'de> Deserialize<'de> for LaboratoryLocalTransferRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LaboratoryLocalTransferRequest
impl JsonSchema for LaboratoryLocalTransferRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LaboratoryLocalTransferRequest
impl RefUnwindSafe for LaboratoryLocalTransferRequest
impl Send for LaboratoryLocalTransferRequest
impl Sync for LaboratoryLocalTransferRequest
impl Unpin for LaboratoryLocalTransferRequest
impl UnsafeUnpin for LaboratoryLocalTransferRequest
impl UnwindSafe for LaboratoryLocalTransferRequest