pub struct LaboratoryTransferRequest {
pub source_id: String,
pub dest_id: String,
pub source_path: String,
pub dest_path: String,
}Expand description
Parameters for Payload::LaboratoryTransfer. Copy source_path from
the source_id laboratory into dest_path of the dest_id laboratory
(cp-style: a directory source_path lands as dest_path/<basename>).
Fields
source_id: Stringdest_id: Stringsource_path: Stringdest_path: StringTrait Implementations
Sourceimpl Clone for LaboratoryTransferRequest
impl Clone for LaboratoryTransferRequest
Sourcefn clone(&self) -> LaboratoryTransferRequest
fn clone(&self) -> LaboratoryTransferRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LaboratoryTransferRequest
impl Debug for LaboratoryTransferRequest
Sourceimpl<'de> Deserialize<'de> for LaboratoryTransferRequest
impl<'de> Deserialize<'de> for LaboratoryTransferRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LaboratoryTransferRequest
impl JsonSchema for LaboratoryTransferRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LaboratoryTransferRequest
impl RefUnwindSafe for LaboratoryTransferRequest
impl Send for LaboratoryTransferRequest
impl Sync for LaboratoryTransferRequest
impl Unpin for LaboratoryTransferRequest
impl UnsafeUnpin for LaboratoryTransferRequest
impl UnwindSafe for LaboratoryTransferRequest