pub struct ScalarFieldsValidation {
pub input_schema: InputSchema,
}Expand description
The fields needed to validate a scalar function’s input behavior.
Fields
input_schema: InputSchemaTrait Implementations
Sourceimpl Clone for ScalarFieldsValidation
impl Clone for ScalarFieldsValidation
Sourcefn clone(&self) -> ScalarFieldsValidation
fn clone(&self) -> ScalarFieldsValidation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScalarFieldsValidation
impl Debug for ScalarFieldsValidation
Sourceimpl<'de> Deserialize<'de> for ScalarFieldsValidation
impl<'de> Deserialize<'de> for ScalarFieldsValidation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScalarFieldsValidation
impl JsonSchema for ScalarFieldsValidation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ScalarFieldsValidation
impl RefUnwindSafe for ScalarFieldsValidation
impl Send for ScalarFieldsValidation
impl Sync for ScalarFieldsValidation
impl Unpin for ScalarFieldsValidation
impl UnsafeUnpin for ScalarFieldsValidation
impl UnwindSafe for ScalarFieldsValidation