pub struct VectorFieldsValidation {
pub input_schema: InputSchema,
pub output_length: Expression,
pub input_split: Expression,
pub input_merge: Expression,
}Expand description
The 4 fields needed to validate a vector function’s split/merge behavior.
Fields
input_schema: InputSchemaoutput_length: Expressioninput_split: Expressioninput_merge: ExpressionTrait Implementations
Sourceimpl Clone for VectorFieldsValidation
impl Clone for VectorFieldsValidation
Sourcefn clone(&self) -> VectorFieldsValidation
fn clone(&self) -> VectorFieldsValidation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VectorFieldsValidation
impl Debug for VectorFieldsValidation
Sourceimpl<'de> Deserialize<'de> for VectorFieldsValidation
impl<'de> Deserialize<'de> for VectorFieldsValidation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VectorFieldsValidation
impl JsonSchema for VectorFieldsValidation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for VectorFieldsValidation
impl RefUnwindSafe for VectorFieldsValidation
impl Send for VectorFieldsValidation
impl Sync for VectorFieldsValidation
impl Unpin for VectorFieldsValidation
impl UnsafeUnpin for VectorFieldsValidation
impl UnwindSafe for VectorFieldsValidation