pub enum RemoteFunction {
Scalar {
description: String,
input_schema: InputSchema,
tasks: Vec<TaskExpression>,
},
Vector {
description: String,
input_schema: InputSchema,
tasks: Vec<TaskExpression>,
output_length: Expression,
input_split: Expression,
input_merge: Expression,
},
}Expand description
A remote function with full metadata.
Remote functions are stored as function.json in repositories and
referenced by remote/owner/repository. They include documentation fields
that inline functions lack.
Variants
Scalar
Produces a single score in [0, 1].
Fields
input_schema: InputSchemaJSON Schema defining the expected input structure.
tasks: Vec<TaskExpression>The list of tasks to execute. Tasks with a map expression are
expanded into multiple instances. Each instance is compiled with
map set to the current integer index.
Receives: input, map (if mapped).
Vector
Produces a vector of scores that sums to 1.
Fields
input_schema: InputSchemaJSON Schema defining the expected input structure.
tasks: Vec<TaskExpression>The list of tasks to execute. Tasks with a map expression are
expanded into multiple instances. Each instance is compiled with
map set to the current integer index.
Receives: input, map (if mapped).
output_length: ExpressionExpression computing the expected output vector length for task outputs.
Receives: input.
input_split: ExpressionExpression transforming input into an input array of the output_length
When the Function is executed with any input from the array,
The output_length should be 1.
Receives: input.
input_merge: ExpressionExpression transforming an array of inputs computed by input_split
into a single Input object for the Function.
Receives: input (as an array).
Implementations
Sourceimpl RemoteFunction
impl RemoteFunction
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the function’s description.
Sourcepub fn input_schema(&self) -> &InputSchema
pub fn input_schema(&self) -> &InputSchema
Returns the function’s input schema.
Sourcepub fn tasks(&self) -> &[TaskExpression]
pub fn tasks(&self) -> &[TaskExpression]
Returns the function’s tasks.
Sourcepub fn output_length(&self) -> Option<&Expression>
pub fn output_length(&self) -> Option<&Expression>
Returns the function’s expected output length, if defined (vector functions only).
Sourcepub fn input_split(&self) -> Option<&Expression>
pub fn input_split(&self) -> Option<&Expression>
Returns the function’s input_split expression, if defined (vector functions only).
Sourcepub fn input_merge(&self) -> Option<&Expression>
pub fn input_merge(&self) -> Option<&Expression>
Returns the function’s input_merge expression, if defined (vector functions only).
pub fn remotes(&self) -> impl Iterator<Item = &RemotePath>