Function execution request and response types.
Function executions run a Function with a Profile against provided input data. Supports four combinations of remote/inline Functions and Profiles:
- Remote Function + Remote Profile (reference both by remote/owner/repository)
- Remote Function + Inline Profile
- Inline Function + Remote Profile
- Inline Function + Inline Profile
Modules
Structs
- Retry
Token - Token that enables reusing votes from a previous function execution.
Functions
- create_
function_ execution_ streaming - Creates a streaming function execution.
- create_
function_ execution_ unary - Creates a function execution (non-streaming).