pub struct FunctionExecutionCreateParamsLog {Show 13 fields
pub function: FullInlineFunctionOrRemoteCommitOptional,
pub profile: InlineProfileOrRemoteCommitOptional,
pub retry_token: Option<String>,
pub from_cache: Option<bool>,
pub reasoning: Option<Reasoning>,
pub strategy: Option<Strategy>,
pub input: InputValueLog,
pub split: Option<bool>,
pub invert: Option<bool>,
pub provider: Option<Provider>,
pub seed: Option<i64>,
pub stream: Option<bool>,
pub continuation: Option<LogReference>,
}Fields
function: FullInlineFunctionOrRemoteCommitOptionalprofile: InlineProfileOrRemoteCommitOptionalretry_token: Option<String>from_cache: Option<bool>reasoning: Option<Reasoning>strategy: Option<Strategy>input: InputValueLogsplit: Option<bool>invert: Option<bool>provider: Option<Provider>seed: Option<i64>stream: Option<bool>continuation: Option<LogReference>Trait Implementations
Sourceimpl Clone for FunctionExecutionCreateParamsLog
impl Clone for FunctionExecutionCreateParamsLog
Sourcefn clone(&self) -> FunctionExecutionCreateParamsLog
fn clone(&self) -> FunctionExecutionCreateParamsLog
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CommandResponse for FunctionExecutionCreateParamsLog
Available on crate feature mcp only.
impl CommandResponse for FunctionExecutionCreateParamsLog
Available on crate feature
mcp only.fn into_mcp(self) -> McpResponseItem
Sourceimpl<'de> Deserialize<'de> for FunctionExecutionCreateParamsLog
impl<'de> Deserialize<'de> for FunctionExecutionCreateParamsLog
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FunctionExecutionCreateParamsLog
impl JsonSchema for FunctionExecutionCreateParamsLog
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FunctionExecutionCreateParamsLog
impl RefUnwindSafe for FunctionExecutionCreateParamsLog
impl Send for FunctionExecutionCreateParamsLog
impl Sync for FunctionExecutionCreateParamsLog
impl Unpin for FunctionExecutionCreateParamsLog
impl UnsafeUnpin for FunctionExecutionCreateParamsLog
impl UnwindSafe for FunctionExecutionCreateParamsLog