pub enum Task {
FunctionExecution(FunctionExecutionTask),
VectorCompletion(VectorCompletionTask),
}Variants
FunctionExecution(FunctionExecutionTask)
VectorCompletion(VectorCompletionTask)
Implementations
Sourceimpl Task
impl Task
pub fn task_path(&self) -> &Vec<u64>
Sourcepub fn snapshot_sort_key(
&self,
) -> (Vec<u64>, Option<u64>, Option<u64>, Option<u64>, u64)
pub fn snapshot_sort_key( &self, ) -> (Vec<u64>, Option<u64>, Option<u64>, Option<u64>, u64)
Returns a sort key that disambiguates concurrent siblings sharing
a task_path. Pulls in the swiss / split / task indices that
distinguish parallel branches so test snapshots are stable across
arrival orders.