Expression

Enum Expression 

pub enum Expression {
    JMESPath(String),
    Starlark(String),
    Special(Special),
}
An expression that can be either JMESPath or Starlark.

Serializes as {"$jmespath": "..."} or {"$starlark": "..."} in JSON.

Examples

JMESPath:

{"$jmespath": "input.items[0].name"}

Starlark:

{"$starlark": "input['items'][0]['name']"}

Variants



JMESPath(String)

A JMESPath expression.



Starlark(String)

A Starlark expression.



Special(Special)

A predefined special expression variant.

Implementations

Source

impl Expression

pub fn compile_one_or_many<T>( &self, params: &Params<'_, '_>, ) -> Result<OneOrMany<T>, ExpressionError>

Compiles the expression, allowing array results.

Returns OneOrMany::One for single values or OneOrMany::Many for arrays. Null values are filtered out from array results. A Single Null value is treated as an empty array.

pub fn compile_one<T>( &self, params: &Params<'_, '_>, ) -> Result<T, ExpressionError>

Compiles the expression, expecting exactly one value.

Accepts a single value or an array with exactly one element. Returns an error if the expression evaluates to null, an empty array, or an array with more than one element.