pub enum ExpressionError {
JmespathError(JmespathError),
StarlarkParseError(String),
StarlarkEvalError(String),
StarlarkConversionError(String),
DeserializationError(Error),
ExpectedOneValueFoundMany,
UnsupportedSpecial,
}Expand description
Errors that can occur when compiling expressions.
Variants
JmespathError(JmespathError)
The JMESPath expression is invalid or failed to evaluate.
StarlarkParseError(String)
The Starlark expression failed to parse.
StarlarkEvalError(String)
The Starlark expression failed to evaluate.
StarlarkConversionError(String)
The Starlark result could not be converted to JSON.
DeserializationError(Error)
The expression result could not be deserialized to the expected type.
ExpectedOneValueFoundMany
Expected a single value but the expression returned multiple.
UnsupportedSpecial
A Special expression variant is not supported for this target type.