pub enum Special {
Input,
Output,
TaskOutputL1Normalized,
TaskOutputWeightedSum,
InputItemsOutputLength,
InputItemsOptionalContextSplit,
InputItemsOptionalContextMerge,
}Expand description
Predefined expression behaviors that require no user-authored code.
Variants
Input
Returns the params input as-is.
Output
Returns the params output as-is.
TaskOutputL1Normalized
L1-normalizes the output. Scalar/Err pass through. Vector: L1 normalize. Vectors: L1 normalize each.
TaskOutputWeightedSum
Weighted sum of the output. Vector → Scalar. Vectors → Vector.
InputItemsOutputLength
Returns the length of input[‘items’] as u64
InputItemsOptionalContextSplit
Splits an input containing items and optionally context into multiple inputs
InputItemsOptionalContextMerge
Merges multiple inputs containing items and optionally context into a single input