pub struct AnyOfInputSchema {
pub any_of: Vec<InputSchema>,
}Expand description
Schema for a union of possible types - input must match at least one.
Fields
any_of: Vec<InputSchema>The possible schemas that the input can match.
Implementations
Sourceimpl AnyOfInputSchema
impl AnyOfInputSchema
Sourcepub fn modalities(&self) -> Modalities
pub fn modalities(&self) -> Modalities
Returns which media modalities are present in any variant.
Sourcepub fn validate_input(&self, input: &InputValue) -> bool
pub fn validate_input(&self, input: &InputValue) -> bool
Validates that an input matches at least one schema in the union.