pub struct ArrayInputSchema {
pub type: ArrayInputSchemaType,
pub description: Option<String>,
pub min_items: Option<u64>,
pub max_items: Option<u64>,
pub items: Box<InputSchema>,
}Expand description
Schema for an array input.
Fields
type: ArrayInputSchemaTypedescription: Option<String>Human-readable description of the array.
min_items: Option<u64>Minimum number of items required.
max_items: Option<u64>Maximum number of items allowed.
items: Box<InputSchema>Schema for each item in the array.
Implementations
Sourceimpl ArrayInputSchema
impl ArrayInputSchema
Sourcepub fn modalities(&self) -> Modalities
pub fn modalities(&self) -> Modalities
Returns which media modalities are present in the item schema.
Sourcepub fn validate_input(&self, input: &InputValue) -> bool
pub fn validate_input(&self, input: &InputValue) -> bool
Validates that an input is an array matching this schema.