pub struct ObjectInputSchema {
pub type: ObjectInputSchemaType,
pub description: Option<String>,
pub properties: IndexMap<String, InputSchema>,
pub required: Option<Vec<String>>,
}Expand description
Schema for an object input with named properties.
Fields
type: ObjectInputSchemaTypedescription: Option<String>Human-readable description of the object.
properties: IndexMap<String, InputSchema>Schema for each property in the object.
required: Option<Vec<String>>List of property names that must be present.
Implementations
Sourceimpl ObjectInputSchema
impl ObjectInputSchema
Sourcepub fn modalities(&self) -> Modalities
pub fn modalities(&self) -> Modalities
Returns which media modalities are present in any property.
Sourcepub fn validate_input(&self, input: &InputValue) -> bool
pub fn validate_input(&self, input: &InputValue) -> bool
Validates that an input is an object matching this schema.