pub struct StringInputSchema {
pub type: StringInputSchemaType,
pub description: Option<String>,
pub enum: Option<Vec<String>>,
}Expand description
Schema for a string input.
Fields
type: StringInputSchemaTypedescription: Option<String>Human-readable description of the string.
enum: Option<Vec<String>>If provided, the string must be one of these values.
Implementations
Sourceimpl StringInputSchema
impl StringInputSchema
Sourcepub fn validate_input(&self, input: &InputValue) -> bool
pub fn validate_input(&self, input: &InputValue) -> bool
Validates that an input is a string matching this schema.