pub struct FunctionInventionRecursiveCreateParamsLog {
pub remote: Remote,
pub overwrite: Option<bool>,
pub state: LogReference,
pub provider: Option<Provider>,
pub agent: InlineAgentBaseWithFallbacksOrRemoteCommitOptional,
pub prompt: InlinePromptOrRemoteCommitOptional,
pub seed: Option<i64>,
pub stream: Option<bool>,
pub max_step_retries: Option<u32>,
pub continuation: Option<LogReference>,
}Fields
remote: Remoteoverwrite: Option<bool>state: LogReferenceprovider: Option<Provider>agent: InlineAgentBaseWithFallbacksOrRemoteCommitOptionalprompt: InlinePromptOrRemoteCommitOptionalseed: Option<i64>stream: Option<bool>max_step_retries: Option<u32>continuation: Option<LogReference>Trait Implementations
Sourceimpl Clone for FunctionInventionRecursiveCreateParamsLog
impl Clone for FunctionInventionRecursiveCreateParamsLog
Sourcefn clone(&self) -> FunctionInventionRecursiveCreateParamsLog
fn clone(&self) -> FunctionInventionRecursiveCreateParamsLog
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CommandResponse for FunctionInventionRecursiveCreateParamsLog
Available on crate feature mcp only.
impl CommandResponse for FunctionInventionRecursiveCreateParamsLog
Available on crate feature
mcp only.fn into_mcp(self) -> McpResponseItem
Sourceimpl<'de> Deserialize<'de> for FunctionInventionRecursiveCreateParamsLog
impl<'de> Deserialize<'de> for FunctionInventionRecursiveCreateParamsLog
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FunctionInventionRecursiveCreateParamsLog
impl JsonSchema for FunctionInventionRecursiveCreateParamsLog
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FunctionInventionRecursiveCreateParamsLog
impl RefUnwindSafe for FunctionInventionRecursiveCreateParamsLog
impl Send for FunctionInventionRecursiveCreateParamsLog
impl Sync for FunctionInventionRecursiveCreateParamsLog
impl Unpin for FunctionInventionRecursiveCreateParamsLog
impl UnsafeUnpin for FunctionInventionRecursiveCreateParamsLog
impl UnwindSafe for FunctionInventionRecursiveCreateParamsLog