pub struct FunctionInventionRecursiveChunkLog {
pub id: String,
pub inventions: Vec<IndexedLogReference>,
pub inventions_errors: Option<bool>,
pub created: u64,
pub object: Object,
pub usage: Option<Usage>,
}Fields
id: Stringinventions: Vec<IndexedLogReference>inventions_errors: Option<bool>created: u64object: Objectusage: Option<Usage>Trait Implementations
Sourceimpl Clone for FunctionInventionRecursiveChunkLog
impl Clone for FunctionInventionRecursiveChunkLog
Sourcefn clone(&self) -> FunctionInventionRecursiveChunkLog
fn clone(&self) -> FunctionInventionRecursiveChunkLog
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CommandResponse for FunctionInventionRecursiveChunkLog
Available on crate feature mcp only.
impl CommandResponse for FunctionInventionRecursiveChunkLog
Available on crate feature
mcp only.fn into_mcp(self) -> McpResponseItem
Sourceimpl<'de> Deserialize<'de> for FunctionInventionRecursiveChunkLog
impl<'de> Deserialize<'de> for FunctionInventionRecursiveChunkLog
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FunctionInventionRecursiveChunkLog
impl JsonSchema for FunctionInventionRecursiveChunkLog
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FunctionInventionRecursiveChunkLog
impl RefUnwindSafe for FunctionInventionRecursiveChunkLog
impl Send for FunctionInventionRecursiveChunkLog
impl Sync for FunctionInventionRecursiveChunkLog
impl Unpin for FunctionInventionRecursiveChunkLog
impl UnsafeUnpin for FunctionInventionRecursiveChunkLog
impl UnwindSafe for FunctionInventionRecursiveChunkLog