pub struct FunctionInventionChunkLog {
pub id: String,
pub completions: Vec<IndexedLogReference>,
pub state: Option<State>,
pub path: Option<RemotePath>,
pub function: Option<FullRemoteFunction>,
pub created: u64,
pub object: Object,
pub usage: Option<Usage>,
pub error: Option<ResponseError>,
}Fields
id: Stringcompletions: Vec<IndexedLogReference>state: Option<State>path: Option<RemotePath>function: Option<FullRemoteFunction>created: u64object: Objectusage: Option<Usage>error: Option<ResponseError>Trait Implementations
Sourceimpl Clone for FunctionInventionChunkLog
impl Clone for FunctionInventionChunkLog
Sourcefn clone(&self) -> FunctionInventionChunkLog
fn clone(&self) -> FunctionInventionChunkLog
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CommandResponse for FunctionInventionChunkLog
Available on crate feature mcp only.
impl CommandResponse for FunctionInventionChunkLog
Available on crate feature
mcp only.fn into_mcp(self) -> McpResponseItem
Sourceimpl Debug for FunctionInventionChunkLog
impl Debug for FunctionInventionChunkLog
Sourceimpl<'de> Deserialize<'de> for FunctionInventionChunkLog
impl<'de> Deserialize<'de> for FunctionInventionChunkLog
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FunctionInventionChunkLog
impl JsonSchema for FunctionInventionChunkLog
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FunctionInventionChunkLog
impl RefUnwindSafe for FunctionInventionChunkLog
impl Send for FunctionInventionChunkLog
impl Sync for FunctionInventionChunkLog
impl Unpin for FunctionInventionChunkLog
impl UnsafeUnpin for FunctionInventionChunkLog
impl UnwindSafe for FunctionInventionChunkLog