pub struct ScalarInputSchemaObject {
pub schema: String,
}Expand description
Schema for WriteInputSchema on scalar functions.
Takes a schema property: a JSON string conforming to functions.expression.ObjectInputSchema.
Fields
schema: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for ScalarInputSchemaObject
impl<'de> Deserialize<'de> for ScalarInputSchemaObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScalarInputSchemaObject
impl JsonSchema for ScalarInputSchemaObject
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl JsonSchema for ScalarInputSchemaObject
impl JsonSchema for ScalarInputSchemaObject