pub struct VectorInputSchemaObject {
pub schema: String,
}Expand description
Schema for WriteInputSchema on vector functions.
Takes a schema property: a JSON string conforming to functions.alpha_vector.expression.VectorFunctionInputSchema.
Fields
schema: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for VectorInputSchemaObject
impl<'de> Deserialize<'de> for VectorInputSchemaObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VectorInputSchemaObject
impl JsonSchema for VectorInputSchemaObject
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl JsonSchema for VectorInputSchemaObject
impl JsonSchema for VectorInputSchemaObject