pub struct DatasetItem {
pub input: InputValue,
pub target: Target,
}Fields
input: InputValuetarget: TargetTrait Implementations
Sourceimpl Clone for DatasetItem
impl Clone for DatasetItem
Sourcefn clone(&self) -> DatasetItem
fn clone(&self) -> DatasetItem
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DatasetItem
impl Debug for DatasetItem
Sourceimpl<'de> Deserialize<'de> for DatasetItem
impl<'de> Deserialize<'de> for DatasetItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DatasetItem
impl JsonSchema for DatasetItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DatasetItem
impl RefUnwindSafe for DatasetItem
impl Send for DatasetItem
impl Sync for DatasetItem
impl Unpin for DatasetItem
impl UnsafeUnpin for DatasetItem
impl UnwindSafe for DatasetItem