pub struct FunctionProfileComputationCreateParams {
pub function: FullInlineFunctionOrRemoteCommitOptional,
pub retry_token: Option<String>,
pub from_cache: Option<bool>,
pub max_retries: Option<u64>,
pub n: u64,
pub dataset: Vec<DatasetItem>,
pub swarm: InlineSwarmBaseOrRemoteCommitOptional,
pub provider: Option<Provider>,
pub seed: Option<i64>,
pub stream: Option<bool>,
}Expand description
Parameters for creating a function profile computation.
Fields
function: FullInlineFunctionOrRemoteCommitOptionalThe function to compute a profile for (inline definition or remote path).
retry_token: Option<String>from_cache: Option<bool>max_retries: Option<u64>n: u64dataset: Vec<DatasetItem>swarm: InlineSwarmBaseOrRemoteCommitOptionalprovider: Option<Provider>seed: Option<i64>stream: Option<bool>Trait Implementations
Sourceimpl Clone for FunctionProfileComputationCreateParams
impl Clone for FunctionProfileComputationCreateParams
Sourcefn clone(&self) -> FunctionProfileComputationCreateParams
fn clone(&self) -> FunctionProfileComputationCreateParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for FunctionProfileComputationCreateParams
impl<'de> Deserialize<'de> for FunctionProfileComputationCreateParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FunctionProfileComputationCreateParams
impl JsonSchema for FunctionProfileComputationCreateParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FunctionProfileComputationCreateParams
impl RefUnwindSafe for FunctionProfileComputationCreateParams
impl Send for FunctionProfileComputationCreateParams
impl Sync for FunctionProfileComputationCreateParams
impl Unpin for FunctionProfileComputationCreateParams
impl UnsafeUnpin for FunctionProfileComputationCreateParams
impl UnwindSafe for FunctionProfileComputationCreateParams