pub struct GetProfileResponse {
pub path: RemotePath,
pub inner: RemoteProfile,
}Fields
path: RemotePathinner: RemoteProfileTrait Implementations
Sourceimpl Clone for GetProfileResponse
impl Clone for GetProfileResponse
Sourcefn clone(&self) -> GetProfileResponse
fn clone(&self) -> GetProfileResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetProfileResponse
impl Debug for GetProfileResponse
Sourceimpl<'de> Deserialize<'de> for GetProfileResponse
impl<'de> Deserialize<'de> for GetProfileResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetProfileResponse
impl JsonSchema for GetProfileResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GetProfileResponse
impl RefUnwindSafe for GetProfileResponse
impl Send for GetProfileResponse
impl Sync for GetProfileResponse
impl Unpin for GetProfileResponse
impl UnsafeUnpin for GetProfileResponse
impl UnwindSafe for GetProfileResponse