pub struct GetFunctionResponse {
pub path: RemotePath,
pub inner: FullRemoteFunction,
}Fields
path: RemotePathinner: FullRemoteFunctionTrait Implementations
Sourceimpl Clone for GetFunctionResponse
impl Clone for GetFunctionResponse
Sourcefn clone(&self) -> GetFunctionResponse
fn clone(&self) -> GetFunctionResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetFunctionResponse
impl Debug for GetFunctionResponse
Sourceimpl<'de> Deserialize<'de> for GetFunctionResponse
impl<'de> Deserialize<'de> for GetFunctionResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetFunctionResponse
impl JsonSchema for GetFunctionResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GetFunctionResponse
impl RefUnwindSafe for GetFunctionResponse
impl Send for GetFunctionResponse
impl Sync for GetFunctionResponse
impl Unpin for GetFunctionResponse
impl UnsafeUnpin for GetFunctionResponse
impl UnwindSafe for GetFunctionResponse