pub struct PlaceholderVectorFunctionTaskExpression {
pub input_schema: InputSchema,
pub output_length: Expression,
pub input_split: Expression,
pub input_merge: Expression,
pub skip: Option<Expression>,
pub map: Option<Expression>,
pub input: WithExpression<InputValueExpression>,
pub output: Expression,
}Expand description
Expression for a placeholder vector function task (pre-compilation).
Like VectorFunctionTaskExpression but without owner/repository/commit.
Always produces an equalized vector of length output_length.
Fields
input_schema: InputSchemaJSON Schema defining the expected input structure.
output_length: ExpressionExpression computing the expected output vector length.
Receives: input.
input_split: ExpressionExpression transforming input into sub-inputs for swiss system.
Receives: input.
input_merge: ExpressionExpression merging sub-inputs back into one input.
Receives: input (as an array).
skip: Option<Expression>If this expression evaluates to true, skip the task. Receives: input.
map: Option<Expression>Expression that evaluates to the number of mapped task instances.
Each instance receives map as an integer index (0-based).
input: WithExpression<InputValueExpression>Expression for the input to pass to the placeholder function.
Receives: input, map (if mapped).
output: ExpressionExpression to transform the equalized vector output.
Receives: input, output as Vector(equalized).
Implementations
Sourceimpl PlaceholderVectorFunctionTaskExpression
impl PlaceholderVectorFunctionTaskExpression
pub fn compile( self, params: &Params<'_, '_>, ) -> Result<PlaceholderVectorFunctionTask, ExpressionError>