pub struct ScalarFunctionTaskExpression {
pub path: RemotePath,
pub skip: Option<Expression>,
pub map: Option<Expression>,
pub input: WithExpression<InputValueExpression>,
pub output: Expression,
}Expand description
Expression for a task that calls a scalar function (pre-compilation).
Fields
path: RemotePathskip: Option<Expression>If this expression evaluates to true, skip the task. Receives: input.
map: Option<Expression>Expression that evaluates to the number of mapped task instances.
Each instance receives map as an integer index (0-based).
input: WithExpression<InputValueExpression>Expression for the input to pass to the function.
Receives: input, map (if mapped).
output: ExpressionExpression to transform the task result into a valid function output.
Receives output which is one of 4 variants:
Scalar(Decimal)- a single scoreVector(Vec<Decimal>)- a vector of scoresVectors(Vec<Vec<Decimal>>)- multiple vectors (from mapped tasks)Err(Value)- an error
The expression must return a TaskOutputOwned that is valid for the parent function’s type:
- For scalar functions: must return
Scalar(value)where value is in [0, 1] - For vector functions: must return
Vector(values)where values sum to ~1 and match the expected length
The function’s final output is computed as a weighted average of all task outputs using profile weights. If a function has only one task, that task’s output becomes the function’s output directly.
Implementations
Sourceimpl ScalarFunctionTaskExpression
impl ScalarFunctionTaskExpression
pub fn url(&self) -> String
Sourcepub fn compile(
self,
params: &Params<'_, '_>,
) -> Result<ScalarFunctionTask, ExpressionError>
pub fn compile( self, params: &Params<'_, '_>, ) -> Result<ScalarFunctionTask, ExpressionError>
Compiles the expression into a concrete ScalarFunctionTask.