pub struct AgentCompletionCreateParams {
pub id: String,
pub inner: Arc<AgentCompletionCreateParams>,
}Fields
id: Stringinner: Arc<AgentCompletionCreateParams>Trait Implementations
Sourceimpl Clone for AgentCompletionCreateParams
impl Clone for AgentCompletionCreateParams
Sourcefn clone(&self) -> AgentCompletionCreateParams
fn clone(&self) -> AgentCompletionCreateParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentCompletionCreateParams
impl Debug for AgentCompletionCreateParams
Sourceimpl<'de> Deserialize<'de> for AgentCompletionCreateParams
impl<'de> Deserialize<'de> for AgentCompletionCreateParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentCompletionCreateParams
impl JsonSchema for AgentCompletionCreateParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentCompletionCreateParams
impl RefUnwindSafe for AgentCompletionCreateParams
impl Send for AgentCompletionCreateParams
impl Sync for AgentCompletionCreateParams
impl Unpin for AgentCompletionCreateParams
impl UnsafeUnpin for AgentCompletionCreateParams
impl UnwindSafe for AgentCompletionCreateParams