pub struct FunctionExecutionCreateParams {
pub id: String,
pub inner: Arc<FunctionExecutionCreateParams>,
}Fields
id: Stringinner: Arc<FunctionExecutionCreateParams>Trait Implementations
Sourceimpl Clone for FunctionExecutionCreateParams
impl Clone for FunctionExecutionCreateParams
Sourcefn clone(&self) -> FunctionExecutionCreateParams
fn clone(&self) -> FunctionExecutionCreateParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for FunctionExecutionCreateParams
impl<'de> Deserialize<'de> for FunctionExecutionCreateParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FunctionExecutionCreateParams
impl JsonSchema for FunctionExecutionCreateParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FunctionExecutionCreateParams
impl RefUnwindSafe for FunctionExecutionCreateParams
impl Send for FunctionExecutionCreateParams
impl Sync for FunctionExecutionCreateParams
impl Unpin for FunctionExecutionCreateParams
impl UnsafeUnpin for FunctionExecutionCreateParams
impl UnwindSafe for FunctionExecutionCreateParams