pub struct LaboratoryExecutionCreateParams {Show 13 fields
pub docker_image: String,
pub builder_agents: Vec<InlineAgentBaseWithFallbacksOrRemoteCommitOptional>,
pub evaluation_agent: Option<InlineAgentBaseWithFallbacksOrRemoteCommitOptional>,
pub builder_messages: Vec<Message>,
pub evaluation_messages: Option<Vec<Message>>,
pub evaluation_output_schema: Option<InputSchema>,
pub builder_continuation: Option<String>,
pub evaluation_continuation: Option<String>,
pub max_evaluation_retries: Option<u32>,
pub persist: Option<bool>,
pub provider: Option<Provider>,
pub seed: Option<i64>,
pub stream: Option<bool>,
}Expand description
Parameters for creating a laboratory execution.
Fields
docker_image: StringDocker image to use for builder containers.
builder_agents: Vec<InlineAgentBaseWithFallbacksOrRemoteCommitOptional>Builder agents — at least one required.
evaluation_agent: Option<InlineAgentBaseWithFallbacksOrRemoteCommitOptional>Evaluation agent for evaluating builder outputs. If not provided, no evaluation is performed.
builder_messages: Vec<Message>Messages for builder agents.
evaluation_messages: Option<Vec<Message>>Messages for the evaluation agent.
evaluation_output_schema: Option<InputSchema>Output schema for evaluation.
builder_continuation: Option<String>Continuation from a previous builder completion, as a base64-encoded string.
evaluation_continuation: Option<String>Continuation from a previous evaluation completion, as a base64-encoded string.
max_evaluation_retries: Option<u32>Maximum number of evaluation retries if validation fails. Defaults to 3 if not specified.
persist: Option<bool>Whether to keep containers after execution. Defaults to false.
provider: Option<Provider>seed: Option<i64>stream: Option<bool>Trait Implementations
Sourceimpl Clone for LaboratoryExecutionCreateParams
impl Clone for LaboratoryExecutionCreateParams
Sourcefn clone(&self) -> LaboratoryExecutionCreateParams
fn clone(&self) -> LaboratoryExecutionCreateParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for LaboratoryExecutionCreateParams
impl<'de> Deserialize<'de> for LaboratoryExecutionCreateParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LaboratoryExecutionCreateParams
impl JsonSchema for LaboratoryExecutionCreateParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LaboratoryExecutionCreateParams
impl RefUnwindSafe for LaboratoryExecutionCreateParams
impl Send for LaboratoryExecutionCreateParams
impl Sync for LaboratoryExecutionCreateParams
impl Unpin for LaboratoryExecutionCreateParams
impl UnsafeUnpin for LaboratoryExecutionCreateParams
impl UnwindSafe for LaboratoryExecutionCreateParams