pub struct ListServersResult {
pub servers: Vec<Server>,
}Expand description
The proxy’s connected upstream MCP servers and their metadata.
Fields
servers: Vec<Server>Trait Implementations
Sourceimpl Clone for ListServersResult
impl Clone for ListServersResult
Sourcefn clone(&self) -> ListServersResult
fn clone(&self) -> ListServersResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListServersResult
impl Debug for ListServersResult
Sourceimpl<'de> Deserialize<'de> for ListServersResult
impl<'de> Deserialize<'de> for ListServersResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListServersResult
impl JsonSchema for ListServersResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListServersResult
impl RefUnwindSafe for ListServersResult
impl Send for ListServersResult
impl Sync for ListServersResult
impl Unpin for ListServersResult
impl UnsafeUnpin for ListServersResult
impl UnwindSafe for ListServersResult