pub struct Icon {
pub src: String,
pub mime_type: Option<String>,
pub sizes: Option<Vec<String>>,
pub theme: Option<IconTheme>,
}Expand description
An icon that can be displayed in a user interface.
Fields
src: StringURL or data URI for the icon.
mime_type: Option<String>MIME type for the icon.
sizes: Option<Vec<String>>Sizes at which the icon can be used (e.g., “48x48”, “96x96”, “any”).
theme: Option<IconTheme>Theme this icon is intended for.