pub enum TaskSupport {
Required,
Optional,
Forbidden,
}Expand description
The tool’s preference for task-augmented execution.
Variants
Required
Clients MUST invoke the tool as a task.
Optional
Clients MAY invoke the tool as a task or normal request.
Forbidden
Clients MUST NOT attempt to invoke the tool as a task.