pub struct ToolAnnotations {
pub title: Option<String>,
pub read_only_hint: Option<bool>,
pub destructive_hint: Option<bool>,
pub idempotent_hint: Option<bool>,
pub open_world_hint: Option<bool>,
}Expand description
Additional metadata about a tool to help clients decide how to display or control its use.
Fields
title: Option<String>A human-readable title for the tool.
read_only_hint: Option<bool>If true, the tool does not modify its environment.
destructive_hint: Option<bool>If true, the tool may perform destructive updates.
idempotent_hint: Option<bool>If true, calling the tool repeatedly with the same arguments has no additional effect.
open_world_hint: Option<bool>If true, the tool interacts with the external world.