pub struct RemoteSwarm {
pub description: String,
pub inner: InlineSwarm,
}Expand description
A validated remote Swarm with metadata and computed content-addressed ID.
Fields
description: Stringinner: InlineSwarmTrait Implementations
Sourceimpl Clone for RemoteSwarm
impl Clone for RemoteSwarm
Sourcefn clone(&self) -> RemoteSwarm
fn clone(&self) -> RemoteSwarm
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteSwarm
impl Debug for RemoteSwarm
Sourceimpl<'de> Deserialize<'de> for RemoteSwarm
impl<'de> Deserialize<'de> for RemoteSwarm
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RemoteSwarm
impl JsonSchema for RemoteSwarm
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteSwarm
impl PartialEq for RemoteSwarm
Sourcefn eq(&self, other: &RemoteSwarm) -> bool
fn eq(&self, other: &RemoteSwarm) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemoteSwarm
impl Serialize for RemoteSwarm
impl StructuralPartialEq for RemoteSwarm