pub struct CacheVoteRequestOwned {
pub agent: InlineAgentBaseWithFallbacksOrRemote,
pub messages: Vec<Message>,
pub responses: Vec<RichContent>,
}Fields
agent: InlineAgentBaseWithFallbacksOrRemotemessages: Vec<Message>responses: Vec<RichContent>Trait Implementations
Sourceimpl Clone for CacheVoteRequestOwned
impl Clone for CacheVoteRequestOwned
Sourcefn clone(&self) -> CacheVoteRequestOwned
fn clone(&self) -> CacheVoteRequestOwned
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CacheVoteRequestOwned
impl Debug for CacheVoteRequestOwned
Sourceimpl<'de> Deserialize<'de> for CacheVoteRequestOwned
impl<'de> Deserialize<'de> for CacheVoteRequestOwned
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CacheVoteRequestOwned
impl JsonSchema for CacheVoteRequestOwned
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CacheVoteRequestOwned
impl RefUnwindSafe for CacheVoteRequestOwned
impl Send for CacheVoteRequestOwned
impl Sync for CacheVoteRequestOwned
impl Unpin for CacheVoteRequestOwned
impl UnsafeUnpin for CacheVoteRequestOwned
impl UnwindSafe for CacheVoteRequestOwned