pub struct VectorResponses(pub Vec<RichContent>);Expand description
The list of response options in a vector completion request.
Each element is a RichContent value that an LLM can vote for.
Responses can be plain text strings or multi-part content containing
text, images, audio, video, or files.
Minimum Length
A vector completion requires at least 2 responses to vote between.
Examples
Plain text responses:
["Yes", "No", "Maybe"]Multimodal responses:
[
[{"type": "text", "text": "Option A"}, {"type": "image_url", "image_url": {"url": "https://example.com/a.png"}}],
[{"type": "text", "text": "Option B"}, {"type": "image_url", "image_url": {"url": "https://example.com/b.png"}}]
]Tuple Fields
0: Vec<RichContent>Trait Implementations
Sourceimpl Clone for VectorResponses
impl Clone for VectorResponses
Sourcefn clone(&self) -> VectorResponses
fn clone(&self) -> VectorResponses
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VectorResponses
impl Debug for VectorResponses
Sourceimpl<'de> Deserialize<'de> for VectorResponses
impl<'de> Deserialize<'de> for VectorResponses
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VectorResponses
impl JsonSchema for VectorResponses
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for VectorResponses
impl RefUnwindSafe for VectorResponses
impl Send for VectorResponses
impl Sync for VectorResponses
impl Unpin for VectorResponses
impl UnsafeUnpin for VectorResponses
impl UnwindSafe for VectorResponses