pub enum MessageExpression {
Developer(DeveloperMessageExpression),
System(SystemMessageExpression),
User(UserMessageExpression),
Assistant(AssistantMessageExpression),
Tool(ToolMessageExpression),
}Expand description
A message with expressions for dynamic content.
This is the expression variant of Message used in function definitions
where message content can be computed from the function input at runtime.
Supports both JMESPath and Starlark expressions.
Variants
Developer(DeveloperMessageExpression)
System(SystemMessageExpression)
User(UserMessageExpression)
Assistant(AssistantMessageExpression)
Tool(ToolMessageExpression)
Implementations
Sourceimpl MessageExpression
impl MessageExpression