pub enum ProviderQuantization {
Int4,
Int8,
Fp4,
Fp6,
Fp8,
Fp16,
Bf16,
Fp32,
Unknown,
}Expand description
Model quantization levels for provider filtering.
Quantization reduces model precision to decrease memory usage and increase inference speed, potentially at the cost of output quality.
Variants
Int4
4-bit integer quantization.
Int8
8-bit integer quantization.
Fp4
4-bit floating point quantization.
Fp6
6-bit floating point quantization.
Fp8
8-bit floating point quantization.
Fp16
16-bit floating point (half precision).
Bf16
16-bit brain floating point.
Fp32
32-bit floating point (full precision).
Unknown
Unknown quantization level.