plugins logs — captured plugin-stderr log tier. One leaf:
list --owner <O> --name <N> --version <V> [--after-id] [--limit]— read the stderr lines captured duringplugins run, paginated by the BIGSERIAL"index"cursor.
Modules
- list
plugins logs list— read captured plugin stderr lines for one plugin coordinate (owner/name/version), ascending by the BIGSERIAL"index"cursor (paginate with--after-id/--limit).