Module list

Module list 

plugins logs list — read captured plugin stderr lines for one plugin coordinate (owner/name/version), ascending by the BIGSERIAL "index" cursor (paginate with --after-id / --limit).

Modules

request_schema
response_schema

Structs

Args
Command
Request
ResponseItem
One captured stderr line from a plugins run invocation.

Enums

Path
Schema

Functions

execute
execute_transform