python — run a Python snippet and return its output as JSON.
Executes --code in the embedded Python runtime with the optional
--input JSON value exposed to the script as the global input,
and returns the script’s output (its trailing expression value,
else captured stdout) as a serde_json::Value. No output → JSON
null.
Modules
Structs
Enums
Functions
Type Aliases
- Response
- Whatever the script produced, as raw JSON (no output →
null).