Module executions

Module executions 

Function execution request and response types.

Function executions run a Function with a Profile against provided input data. Supports four combinations of remote/inline Functions and Profiles:

  • Remote Function + Remote Profile (reference both by remote/owner/repository)
  • Remote Function + Inline Profile
  • Inline Function + Remote Profile
  • Inline Function + Inline Profile

Modules

request
response
Response types for function executions.

Structs

RetryToken
Token that enables reusing votes from a previous function execution.

Functions

create_function_execution_streaming
Creates a streaming function execution. Returns (Stream<Chunk>, Notifier); see [crate::agent::completions::http::create_agent_completion_streaming] for the demux + handler semantics.
create_function_execution_unary
Creates a function execution (non-streaming).