pub struct FunctionInventionCreateParams {
pub remote: Option<Remote>,
pub overwrite: Option<bool>,
pub state: ParamsStateOrRemoteCommitOptional,
pub provider: Option<Provider>,
pub agent: InlineAgentBaseWithFallbacksOrRemoteCommitOptional,
pub prompt: InlinePromptOrRemoteCommitOptional,
pub seed: Option<i64>,
pub stream: Option<bool>,
pub max_step_retries: Option<u32>,
pub continuation: Option<String>,
}Fields
remote: Option<Remote>overwrite: Option<bool>state: ParamsStateOrRemoteCommitOptionalprovider: Option<Provider>agent: InlineAgentBaseWithFallbacksOrRemoteCommitOptionalprompt: InlinePromptOrRemoteCommitOptionalseed: Option<i64>stream: Option<bool>max_step_retries: Option<u32>Maximum number of retries per invention step. Each step is one agent completion (which itself may loop internally via tool calls). If the step’s validation still fails after the agent loop ends, the step is retried up to this many times. Defaults to 3 if not specified.
continuation: Option<String>Continuation from a previous completion, as a base64-encoded string.