Module http

Module http 

HTTP client for the ObjectiveAI API.

This module provides the HTTP client implementation for making requests to the ObjectiveAI API. It supports both unary (request-response) and streaming (Server-Sent Events) communication patterns.

Feature Flag

This module is only available when the http feature is enabled (default).

Components

  • HttpClient - The main client for making API requests
  • HttpError - Error types for HTTP operations

Modules

viewer
Viewer HTTP client + request wire shapes.

Structs

HttpClient
HTTP client for making requests to the ObjectiveAI API.
Notifier
Client-side handle for sending notifies to a running agent completion (or any other streaming endpoint) over the same WS that carries the chunk stream.
RejectHandler
Default handler that 501s every server_request. Used when the calling client doesn’t host objectiveai-mcp — agents that declare client_objectiveai_mcp will see this and fall through to the next fallback agent on the server side.

Enums

HttpError
Errors that can occur during HTTP operations.

Traits

McpHandler
Handler for inbound server_request frames on a streaming WS.