Vector completion API types.
Vector completions produce numbers instead of text. Given a prompt and a set of possible responses, vector completions:
- Run multiple agent completions (one per agent in the Swarm)
- Force each completion to select one of the predefined responses
- Combine the selections using explicit weights (the “profile”)
- Return a vector of scores that sums to 1
Use vector completions for: picking a winner, ranking options, classification, and producing machine-usable scoring outputs.
Modules
- completions
- Vector completions request and response types.